@@ -2,4 +2,4 @@
 
 A minimalistic wrapper to AWS DynamoDB
 """
-from LucidDynamodb.Operations import *
+from LucidDynamodb.operations import *
\ No newline at end of file
